@@ -6,6 +6,8 @@
 #include "pixel_console.hpp"
 #include "system.hpp"
 
+#include <optional>
+
 class FullConsole
 {
     uint32_t fg = color::light_green;
@@ -64,7 +66,10 @@ public:
     Vec2i get_size() const { return Vec2i{console->get_size()}; }
     Vec2i get_tile_size() const { return Vec2i{console->get_char_size()}; }
 
-    void put(Vec2i pos, uint32_t c) { console->put(pos.x, pos.y, fg, bg, c); }
+    //void put(Vec2i pos, uint32_t c) { console->put(pos.x, pos.y, fg, bg, c); }
+    void put(Vec2i pos, uint32_t c, std::optional<uint32_t> fg_ = std::nullopt, std::optional<uint32_t> bg_ = std::nullopt) {
+        console->put(pos.x, pos.y, fg_.value_or(fg), bg_.value_or(bg), c);
+    }
     void text(Vec2i pos, std::string const& txt)
     {
         console->text(pos.x, pos.y, txt, fg, bg);
