@@ -64,6 +64,9 @@ void init()
 
 std::shared_ptr<Screen> open_display(int width, int height, bool full_screen)
 {
+    if (m.screen != nullptr) {
+        return m.screen;
+    }
     init();
     Screen::Settings settings{.screen = full_screen ? ScreenType::Full
                                                     : ScreenType::Window,
@@ -77,7 +80,7 @@ std::shared_ptr<Screen> open_display(int width, int height, bool full_screen)
     m.context = std::make_shared<pix::Context>(realw, realh, 0);
     m.context->vpscale = m.screen->get_scale();
 
-    m.sys->add_listener([](AnyEvent e) {
+    m.sys->add_listener([](AnyEvent const& e) {
         if (std::holds_alternative<ResizeEvent>(e)) {
             auto [w, h] = m.screen->get_size();
             m.context->target_size = Vec2f(w, h);
@@ -104,16 +107,6 @@ void save_png(gl::TexRef const& tex, fs::path const& file_name)
     pix::save_png(img, file_name.string());
 }
 
-// gl_wrap::TexRef load_png(fs::path const& file_name)
-//{
-//     auto image = pix::load_png(file_name);
-//     image.flip();
-//
-//     auto tex = std::make_shared<gl_wrap::Texture>(
-//         image.width, image.height, image.ptr, GL_RGBA, image.format);
-//     return gl_wrap::TexRef{tex};
-// }
-
 std::shared_ptr<FreetypeFont> load_font(fs::path const& name, int size)
 {
     return std::make_shared<FreetypeFont>(name.string().c_str(), size);
@@ -153,6 +146,8 @@ PYBIND11_MODULE(_pixpy, mod)
     add_console_class(mod);
 
     add_draw_functions(tc);
+    tc.def_property_readonly(
+        "size", [](gl::TexRef& self) { return Vec2f{self.width(), self.height()}; });
 
     add_font_class(mod);
 
@@ -172,9 +167,6 @@ PYBIND11_MODULE(_pixpy, mod)
             "Opens a new window with the given size. This also initializes pix "
             "and is expected to have been called before any other pix calls.");
     mod.def("get_display", [] { return m.screen; });
-    mod.def(
-        "get_event", [] { return m.sys->next_event(); },
-        "Get the next event. Returns _NoEvent_ when there are no more events.");
     mod.def(
         "all_events", [] { return m.sys->all_events(); },
         "Return a list of all pending events.");
