@@ -14,8 +14,8 @@
 namespace py = pybind11;
 namespace gl = gl_wrap;
 
-gl::TexRef text_to_image(FreetypeFont& font, std::string const& text, int size,
-                         uint32_t color)
+inline gl::TexRef text_to_image(FreetypeFont& font, std::string const& text,
+                                int size, uint32_t color)
 {
     font.set_pixel_size(size);
     auto [w, h] = font.text_size(text);
@@ -34,6 +34,8 @@ inline auto add_font_class(py::module_ const& mod)
 {
     py::class_<FreetypeFont, std::shared_ptr<FreetypeFont>>(mod, "Font")
         .def("make_image", &text_to_image, py::arg("text"), py::arg("size"),
-             py::arg("color") = 0xffffffff)
-        .def_readonly_static("UNSCII_FONT", &FreetypeFont::unscii);
+             py::arg("color") = 0xffffffff,
+             "Create an image containing the given text.")
+        .def_readonly_static("UNSCII_FONT", &FreetypeFont::unscii,
+                             "Get a reference to the built in unscii font.");
 }
