@@ -111,6 +111,10 @@ inline void add_vec2_class(py::module_& mod)
             "converts automatically.")
         .def_readonly("x", &Vec2i::x)
         .def_readonly("y", &Vec2i::y)
+        .def("random",
+             [](Vec2i self) {
+                 return Vec2i{rand() % self.x, rand() % self.y};
+             })
         .def("__eq__", [](const Vec2i& a, Vec2i const& b) { return a == b; })
         .def("__ne__", [](const Vec2i& a, Vec2i const& b) { return a != b; })
         .def("__getitem__",
